@@ -7,7 +7,7 @@ Panda::XS - useful features and typemaps for XS modules.
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.1.0';
 require Panda::XSLoader;
 Panda::XSLoader::load();
 
@@ -1412,6 +1412,46 @@ Generic form of call_super/call_next_method/call_next_maybe. 'type' is either xs
 
 
 
+=head1 C MACROS
+
+=head4 XS_HV_ITER(hv,code)
+
+Iterates through perl hash very fast. On each iteration executes C<code>, current hash entry is accessible via C<HE* he>
+variable. Use perl API's C<HeVAL>, C<HeKEY>, C<HeKLEN> to extract value and key from hash entry.
+
+C<hv> must be a non-null HV* variable. Doesn't handle tied hashes.
+
+=head4 XS_HV_ITER_NU(hv,code)
+
+Same as C<XS_HV_ITER> but skips entries whose values are undefs. _NU stands for 'not undef'.
+
+=head4 XS_AV_ITER(av,code)
+
+Iterates through perl array very fast. On each iteration executes C<code>, current array element is accessible via C<SV* elem>
+variable. Keep in mind that it might be a NULL pointer in case if current slot in array is empty.
+
+For example, in this case
+
+    my @arr;
+    $arr[1] = undef;
+    $arr[3] = 10;
+    
+slots 0 and 2 are empty. Slot 1 is not empty but it's value is undefined.
+Don't confuse empty slot with undefined values, empty slot is an absence of SV* variable, while undefined value is a legal
+SV* variable for which SvOK(elem) returns false.
+
+C<av> must be a non-null AV* variable. Doesn't handle tied arrays.
+
+=head4 XS_AV_ITER_NE(av,code)
+
+Same as C<XS_AV_ITER> but skips empty slots. _NE stands for 'not empty'.
+
+=head4 XS_AV_ITER_NU(av,code)
+
+Same as C<XS_AV_ITER> but skips empty slots and undefined emelents. _NU stands for 'not undef'.
+
+
+
 =head1 PERL FUNCTIONS
 
 =head4 obj2hv ($obj)
