@@ -10,9 +10,8 @@ namespace panda {
 
 static long int void_refcnt = 1;
 
-template < typename T >
-struct HasRetain
-{
+template <typename T>
+struct HasRetain {
     typedef char yes;
     typedef char no[2];
 
@@ -26,9 +25,8 @@ struct HasRetain
     static const bool value = sizeof( yes ) == sizeof( test< mixed_type >( NULL ) );
 };
 
-template < typename T >
-struct HasRelease
-{
+template <typename T>
+struct HasRelease {
     typedef char yes;
     typedef char no[2];
 
@@ -47,7 +45,8 @@ struct IsRefCounted {
     static const bool value = HasRelease<T>::value && HasRetain<T>::value;
 };
 
-struct RefCounted {
+class RefCounted {
+public:
     void    retain  () const { ++_refcnt; }
     void    release () const { if (--_refcnt <= 0) delete this; }
     int32_t refcnt  () const { return _refcnt; }
@@ -63,10 +62,7 @@ class shared_ptr {};
 
 template <typename T>
 class shared_ptr<T, true> {
-    private:
-    T* ptr;
-
-    public:
+public:
     typedef T element_type;
 
     shared_ptr () : ptr(NULL) {}
@@ -109,33 +105,22 @@ class shared_ptr<T, true> {
         operator=(p);
     }
 
-    T* operator -> () const { return ptr; }
-    T& operator* () const { return *ptr; }
-    operator T* () const { return ptr; }
-    T* get () const { return ptr; }
-    operator bool () const { return ptr ? true : false; }
+    T* operator ->   () const { return ptr; }
+    T& operator*     () const { return *ptr; }
+       operator T*   () const { return ptr; }
+       operator bool () const { return ptr ? true : false; }
+
+    T*       get       () const { return ptr; }
     long int use_count () const { return ptr->refcnt(); }
-    bool unique () const { return ptr->refcnt() == 1; }
+    bool     unique    () const { return ptr->refcnt() == 1; }
+
+private:
+    T* ptr;
 };
 
 template <typename T>
 class shared_ptr<T, false> {
-    private:
-    T*   ptr;
-    long int* refcnt;
-
-    void refcnt_inc () {
-        ++*refcnt;
-    }
-
-    void refcnt_dec () {
-        if (--*refcnt <= 0) {
-            delete ptr;
-            delete refcnt;
-        }
-    }
-
-    public:
+public:
     typedef T element_type;
 
     shared_ptr () : ptr(NULL), refcnt(&void_refcnt) {
@@ -186,15 +171,31 @@ class shared_ptr<T, false> {
         operator=(p);
     }
 
-    T* operator-> () const { return ptr; }
-    T& operator* () const { return *ptr; }
-    operator T* () const { return ptr; }
-    T* get () const { return ptr; }
-    operator bool() const { return ptr ? true : false; }
-    long int use_count() const { return *refcnt; }
-    bool unique() const { return *refcnt == 1; }
+    T* operator->    () const { return ptr; }
+    T& operator*     () const { return *ptr; }
+       operator T*   () const { return ptr; }
+       operator bool () const { return ptr ? true : false; }
+
+    T*       get       () const { return ptr; }
+    long int use_count () const { return *refcnt; }
+    bool     unique    () const { return *refcnt == 1; }
 
     template<typename U, bool A> friend class shared_ptr;
+
+private:
+    T*   ptr;
+    long int* refcnt;
+
+    void refcnt_inc () {
+        ++*refcnt;
+    }
+
+    void refcnt_dec () {
+        if (--*refcnt <= 0) {
+            delete ptr;
+            delete refcnt;
+        }
+    }
 };
 
 template <typename T1, typename T2>
